@@ -118,11 +118,12 @@ SendFormats(struct upnphttp *h, const char *sformat)
 static char *
 tivo_unescape_tag(char *tag)
 {
-	modifyString(tag, "&amp;amp;", "&amp;");
-	modifyString(tag, "&amp;amp;lt;", "&lt;");
-	modifyString(tag, "&amp;lt;", "&lt;");
-	modifyString(tag, "&amp;amp;gt;", "&gt;");
-	modifyString(tag, "&amp;gt;", "&gt;");
+	modifyString(tag, "&amp;amp;", "&amp;", 1);
+	modifyString(tag, "&amp;amp;lt;", "&lt;", 1);
+	modifyString(tag, "&amp;lt;", "&lt;", 1);
+	modifyString(tag, "&amp;amp;gt;", "&gt;", 1);
+	modifyString(tag, "&amp;gt;", "&gt;", 1);
+	modifyString(tag, "&amp;quot;", "&quot;", 1);
 	return tag;
 }
 
@@ -185,13 +186,8 @@ callback(void *args, int argc, char **argv, char **azColName)
 			episode = strstr(title, " - ");
 			if( episode )
 			{
-				strcatf(str, "<Title>%.*s</Title>"
-				             "<EpisodeTitle>%s</EpisodeTitle>", 
-				             (int)(episode-title), title, episode+3);
-			}
-			else
-			{
-				strcatf(str, "<Title>%s</Title>", title);
+				strcatf(str, "<EpisodeTitle>%s</EpisodeTitle>", episode+3);
+				*episode = '\0';
 			}
 			if( date )
 			{
@@ -202,13 +198,13 @@ callback(void *args, int argc, char **argv, char **azColName)
 				strcatf(str, "<CaptureDate>0x%X</CaptureDate>", (unsigned int)mktime(&tm));
 			}
 			if( comment )
-				strcatf(str, "<Description>%s</Description>", comment);
+				strcatf(str, "<Description>%s</Description>", tivo_unescape_tag(comment));
 		}
 		else
 		{
 			return 0;
 		}
-		strcatf(str, "<Title>%s</Title>", tivo_unescape_tag(title));
+		strcatf(str, "<Title>%s</Title>", title);
 		if( artist ) {
 			strcatf(str, "<ArtistName>%s</ArtistName>", tivo_unescape_tag(artist));
 		}
@@ -308,7 +304,7 @@ SendItemDetails(struct upnphttp *h, int64_t item)
 	args.requested = 1;
 	xasprintf(&sql, SELECT_COLUMNS
 	               "from OBJECTS o left join DETAILS d on (d.ID = o.DETAIL_ID)"
-		       " where o.DETAIL_ID = %lld group by o.DETAIL_ID", item);
+		       " where o.DETAIL_ID = %lld group by o.DETAIL_ID", (long long)item);
 	DPRINTF(E_DEBUG, L_TIVO, "%s\n", sql);
 	ret = sqlite3_exec(db, sql, callback, (void *) &args, &zErrMsg);
 	free(sql);
